color = 1
color-severity-low = green
color-severity-medium = yellow
only = 1
severity = 1
verbose = 9

[Bangs::ProhibitBitwiseOperators]

[Bangs::ProhibitCommentedOutCode]

[Bangs::ProhibitDebuggingModules]

[-Bangs::ProhibitFlagComments]

[Bangs::ProhibitNoPlan]

[Bangs::ProhibitNumberedNames]

[Bangs::ProhibitRefProtoOrProto]

[Bangs::ProhibitUselessRegexModifiers]

[Bangs::ProhibitVagueNames]

[BuiltinFunctions::ProhibitBooleanGrep]

[BuiltinFunctions::ProhibitComplexMappings]

[BuiltinFunctions::ProhibitLvalueSubstr]

[BuiltinFunctions::ProhibitReverseSortBlock]

[BuiltinFunctions::ProhibitSleepViaSelect]

[BuiltinFunctions::ProhibitStringyEval]
allow_includes = 1

[BuiltinFunctions::ProhibitStringySplit]

[BuiltinFunctions::ProhibitUniversalCan]

[BuiltinFunctions::ProhibitUniversalIsa]

[BuiltinFunctions::ProhibitVoidGrep]

[BuiltinFunctions::ProhibitVoidMap]

[BuiltinFunctions::RequireBlockGrep]

[BuiltinFunctions::RequireBlockMap]

[BuiltinFunctions::RequireGlobFunction]

[BuiltinFunctions::RequireSimpleSortBlock]

[ClassHierarchies::ProhibitAutoloading]

[ClassHierarchies::ProhibitExplicitISA]

[ClassHierarchies::ProhibitOneArgBless]

[CodeLayout::ProhibitFatCommaNewline]

[CodeLayout::ProhibitHardTabs]

[-CodeLayout::ProhibitHashBarewords]

[CodeLayout::ProhibitIfIfSameLine]

[CodeLayout::ProhibitParensWithBuiltins]

[CodeLayout::ProhibitQuotedWordLists]

[CodeLayout::ProhibitTrailingWhitespace]

[-CodeLayout::RequireASCII]

[CodeLayout::RequireConsistentNewlines]

[CodeLayout::RequireFinalSemicolon]

[-CodeLayout::RequireTidyCode]

[CodeLayout::RequireTrailingCommaAtNewline]

[CodeLayout::RequireTrailingCommas]

[CodeLayout::RequireUseUTF8]

[Compatibility::ConstantLeadingUnderscore]

[Compatibility::ConstantPragmaHash]

[Compatibility::Gtk2Constants]

[Compatibility::PerlMinimumVersionAndWhy]

[-Compatibility::PodMinimumVersion]

[Compatibility::ProhibitThreeArgumentOpen]

[Compatibility::ProhibitUnixDevNull]

[ControlStructures::ProhibitCStyleForLoops]

[ControlStructures::ProhibitCascadingIfElse]

[ControlStructures::ProhibitDeepNests]

[ControlStructures::ProhibitLabelsWithSpecialBlockNames]

[ControlStructures::ProhibitMutatingListFunctions]

[ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions]

[-ControlStructures::ProhibitPostfixControls]

[ControlStructures::ProhibitUnlessBlocks]

[ControlStructures::ProhibitUnreachableCode]

[ControlStructures::ProhibitUntilBlocks]

[Documentation::PodSpelling]
spell_command = aspell list --lang en_US
stop_words = KENTNL

[Documentation::ProhibitAdjacentLinks]

[Documentation::ProhibitBadAproposMarkup]

[Documentation::ProhibitDuplicateHeadings]

[Documentation::ProhibitDuplicateSeeAlso]

[Documentation::ProhibitLinkToSelf]

[Documentation::ProhibitParagraphEndComma]

[Documentation::ProhibitParagraphTwoDots]

[Documentation::ProhibitUnbalancedParens]

[Documentation::ProhibitVerbatimMarkup]

[Documentation::RequireEndBeforeLastPod]

[Documentation::RequireFinalCut]

[Documentation::RequireLinkedURLs]

[-Documentation::RequirePODUseEncodingUTF8]

[Documentation::RequirePackageMatchesPodName]

[Documentation::RequirePodAtEnd]

[Documentation::RequirePodLinksIncludeText]

[-Documentation::RequirePodSections]

[-Editor::RequireEmacsFileVariables]

[ErrorHandling::RequireCarping]

[ErrorHandling::RequireCheckingReturnValueOfEval]

[ErrorHandling::RequireUseOfExceptions]

[InputOutput::ProhibitBacktickOperators]

[InputOutput::ProhibitBarewordFileHandles]

[InputOutput::ProhibitExplicitStdin]

[InputOutput::ProhibitInteractiveTest]

[InputOutput::ProhibitJoinedReadline]

[InputOutput::ProhibitOneArgSelect]

[InputOutput::ProhibitReadlineInForLoop]

[InputOutput::ProhibitTwoArgOpen]

[InputOutput::RequireBracedFileHandleWithPrint]

[InputOutput::RequireBriefOpen]

[InputOutput::RequireCheckedClose]

[InputOutput::RequireCheckedOpen]

[InputOutput::RequireCheckedSyscalls]

[InputOutput::RequireEncodingWithUTF8Layer]

[Lax::ProhibitComplexMappings::LinesNotStatements]

[Lax::ProhibitEmptyQuotes::ExceptAsFallback]

[Lax::ProhibitLeadingZeros::ExceptChmod]

[Lax::ProhibitStringyEval::ExceptForRequire]

[Lax::RequireEndWithTrueConst]

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = diagnostics feature perlversion strict warnings utf8

[Miscellanea::ProhibitFormats]

[Miscellanea::ProhibitTies]

[Miscellanea::ProhibitUnrestrictedNoCritic]

[-Miscellanea::ProhibitUselessNoCritic]

[-Miscellanea::RequireRcsKeywords]

[Miscellanea::TextDomainPlaceholders]

[Miscellanea::TextDomainUnused]

[Modules::PerlMinimumVersion]

[Modules::ProhibitAutomaticExportation]

[Modules::ProhibitConditionalUseStatements]

[Modules::ProhibitEvilModules]

[Modules::ProhibitExcessMainComplexity]

[Modules::ProhibitModuleShebang]

[Modules::ProhibitMultiplePackages]

[Modules::ProhibitPOSIXimport]

[Modules::ProhibitUseQuotedVersion]

[Modules::RequireBarewordIncludes]

[Modules::RequireEndWithOne]

[-Modules::RequireExplicitInclusion]

[-Modules::RequireExplicitPackage]

[Modules::RequireFilenameMatchesPackage]

[Modules::RequireNoMatchVarsWithUseEnglish]

[Modules::RequirePerlVersion]

[Modules::RequireVersionVar]

[-Moose::ProhibitMultipleWiths]

[Moose::ProhibitNewMethod]

[Moose::RequireCleanNamespace]

[Moose::RequireMakeImmutable]

[NamingConventions::Capitalization]

[NamingConventions::ProhibitAmbiguousNames]

[NamingConventions::ProhibitMixedCaseSubs]

[NamingConventions::ProhibitMixedCaseVars]

[Objects::ProhibitIndirectSyntax]

[References::ProhibitDoubleSigils]

[RegularExpressions::ProhibitCaptureWithoutTest]

[RegularExpressions::ProhibitComplexRegexes]

[RegularExpressions::ProhibitEnumeratedClasses]

[RegularExpressions::ProhibitEscapedMetacharacters]

[RegularExpressions::ProhibitFixedStringMatches]

[RegularExpressions::ProhibitSingleCharAlternation]

[RegularExpressions::ProhibitUnusedCapture]

[RegularExpressions::ProhibitUnusualDelimiters]

[RegularExpressions::RequireBracesForMultiline]

[RegularExpressions::RequireDotMatchAnything]

[RegularExpressions::RequireExtendedFormatting]

[RegularExpressions::RequireLineBoundaryMatching]

[Subroutines::ProhibitAmpersandSigils]

[Subroutines::ProhibitBuiltinHomonyms]

[Subroutines::ProhibitCallsToUndeclaredSubs]

[Subroutines::ProhibitCallsToUnexportedSubs]

[Subroutines::ProhibitExcessComplexity]

[Subroutines::ProhibitExplicitReturnUndef]

[Subroutines::ProhibitExportingUndeclaredSubs]

[Subroutines::ProhibitManyArgs]

[Subroutines::ProhibitNestedSubs]

[Subroutines::ProhibitQualifiedSubDeclarations]

[Subroutines::ProhibitReturnSort]

[Subroutines::ProhibitSubroutinePrototypes]

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w

[Subroutines::ProtectPrivateSubs]

[Subroutines::RequireArgUnpacking]

[Subroutines::RequireFinalReturn]

[TestingAndDebugging::ProhibitNoStrict]

[TestingAndDebugging::ProhibitNoWarnings]

[TestingAndDebugging::ProhibitProlongedStrictureOverride]

[TestingAndDebugging::RequireTestLabels]

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Moose Moo

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Moose Moo

[Tics::ProhibitLongLines]
base_max = 130

[Tics::ProhibitManyArrows]

[Tics::ProhibitUseBase]

[ValuesAndExpressions::ConstantBeforeLt]

[ValuesAndExpressions::NotWithCompare]

[ValuesAndExpressions::ProhibitArrayAssignAref]

[ValuesAndExpressions::ProhibitBarewordDoubleColon]

[ValuesAndExpressions::ProhibitCommaSeparatedStatements]

[ValuesAndExpressions::ProhibitComplexVersion]

[ValuesAndExpressions::ProhibitConstantPragma]

[ValuesAndExpressions::ProhibitDuplicateHashKeys]

[-ValuesAndExpressions::ProhibitEmptyCommas]

[ValuesAndExpressions::ProhibitEmptyQuotes]

[ValuesAndExpressions::ProhibitEscapedCharacters]

[ValuesAndExpressions::ProhibitFiletest_f]

[ValuesAndExpressions::ProhibitImplicitNewlines]

[ValuesAndExpressions::ProhibitInterpolationOfLiterals]

[ValuesAndExpressions::ProhibitLeadingZeros]

[ValuesAndExpressions::ProhibitLongChainsOfMethodCalls]

[-ValuesAndExpressions::ProhibitMagicNumbers]

[ValuesAndExpressions::ProhibitMismatchedOperators]

[ValuesAndExpressions::ProhibitMixedBooleanOperators]

[ValuesAndExpressions::ProhibitNoisyQuotes]

[ValuesAndExpressions::ProhibitNullStatements]

[ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters]

[ValuesAndExpressions::ProhibitSpecialLiteralHeredocTerminator]

[ValuesAndExpressions::ProhibitUnknownBackslash]

[ValuesAndExpressions::ProhibitVersionStrings]

[ValuesAndExpressions::RequireConstantOnLeftSideOfEquality]

[ValuesAndExpressions::RequireConstantVersion]

[-ValuesAndExpressions::RequireInterpolationOfMetachars]

[ValuesAndExpressions::RequireNumberSeparators]

[ValuesAndExpressions::RequireNumericVersion]

[ValuesAndExpressions::RequireQuotedHeredocTerminator]

[ValuesAndExpressions::RequireUpperCaseHeredocTerminator]

[ValuesAndExpressions::RestrictLongStrings]

[ValuesAndExpressions::UnexpandedSpecialLiteral]

[Variables::ProhibitAugmentedAssignmentInDeclaration]

[Variables::ProhibitConditionalDeclarations]

[Variables::ProhibitEvilVariables]

[Variables::ProhibitLocalVars]

[Variables::ProhibitMatchVars]

[Variables::ProhibitPackageVars]

[Variables::ProhibitPerl4PackageNames]

[-Variables::ProhibitPunctuationVars]

[Variables::ProhibitReusedNames]

[Variables::ProhibitUnusedVariables]

[Variables::ProhibitUnusedVarsStricter]

[Variables::ProtectPrivateVars]

[Variables::RequireInitializationForLocalVars]

[Variables::RequireLexicalLoopIterators]

[Variables::RequireLocalizedPunctuationVars]

[Variables::RequireNegativeIndices]
